@@ -3,18 +3,17 @@
 import json
 import os
 import yaml
-from argparse import Action, Namespace
+from argparse import Action
 from typing import Dict, Union
 
 from .actions import _is_action_value_list
+from .namespace import strip_meta
 from .optionals import (
     argcomplete_warn_redraw_prompt,
     import_jsonschema,
     jsonschemaValidationError,
 )
 from .util import (
-    namespace_to_dict,
-    strip_meta,
     yamlParserError,
     yamlScannerError,
     _load_config,
@@ -90,9 +89,7 @@ class ActionJsonSchema(Action):
             value = [value]
         for num, val in enumerate(value):
             try:
-                val, fpath = _load_config(val, enable_path=self._enable_path, flat_namespace=False)
-                if isinstance(val, Namespace):
-                    val = namespace_to_dict(val)
+                val, fpath = _load_config(val, enable_path=self._enable_path)
                 path_meta = val.pop('__path__') if isinstance(val, dict) and '__path__' in val else None
                 self._validator.validate(val)
                 if path_meta is not None:
@@ -102,7 +99,7 @@ class ActionJsonSchema(Action):
                 value[num] = val
             except (TypeError, ValueError, yamlParserError, yamlScannerError, jsonschemaValidationError) as ex:
                 elem = '' if not islist else ' element '+str(num+1)
-                raise TypeError('Parser key "'+self.dest+'"'+elem+': '+str(ex)) from ex
+                raise TypeError(f'Parser key "{self.dest}"{elem}: {ex}') from ex
         return value if islist else value[0]
 
 
@@ -135,5 +132,5 @@ class ActionJsonSchema(Action):
                 msg = 'value not yet valid, '
             else:
                 schema = json.dumps(self._validator.schema, indent=2, sort_keys=True).replace('\n', '\n  ')
-                msg += 'required to be valid according to schema:\n  '+schema+'\n'
+                msg += f'required to be valid according to schema:\n  {schema}\n'
             return argcomplete_warn_redraw_prompt(prefix, msg)
